@@ -123,6 +123,8 @@ void bam_destroy_header_hash(bam_header_t *header);
 #define BAM_FQCFAIL      512
 /*! @abstract optical or PCR duplicate */
 #define BAM_FDUP        1024
+/*! @abstract supplementary alignment */
+#define BAM_FSUPPLEMENTARY 2048
 
 #define BAM_OFDEC          0
 #define BAM_OFHEX          1
